@@ -1,5 +1,5 @@
 package Form::Tiny::Path;
-$Form::Tiny::Path::VERSION = '2.24';
+$Form::Tiny::Path::VERSION = '2.25';
 use v5.10;
 use strict;
 use warnings;
@@ -113,10 +113,21 @@ sub clone
 	return $self->new(path => [@{$self->path}], meta => [@{$self->meta}]);
 }
 
+sub prepend
+{
+	my ($self, $meta, $key) = @_;
+	$key //= $array_marker
+		if $meta eq 'ARRAY';
+
+	unshift @{$self->path}, $key;
+	unshift @{$self->meta}, $meta;
+	return $self;
+}
+
 sub append
 {
 	my ($self, $meta, $key) = @_;
-	$key = $array_marker
+	$key //= $array_marker
 		if $meta eq 'ARRAY';
 
 	push @{$self->path}, $key;
